@@ -30,18 +30,15 @@
 #'   afterwards. If you prefer automatic mirroring of in memory cache and cache 
 #'   on disk 
 #'
-#' @param friendly deprecated
-#' @param requestFrom deprecated
-#' @param userAgent deprecated
 #' 
 #'
 #' @examples 
 #' library(wikipediatrend)
-#' wp_trend(page        = c("Cheese", "K\u00e4se"),
-#'          from        = "2014-11-01", 
-#'          to          = "2014-11-30", 
-#'          lang        = c("en", "de"),
-#'          file        = wp_cache_file()
+#' wp_trend(  page        = c("Cheese", "K\u00e4se"),
+#'            from        = "2014-11-01", 
+#'            to          = "2014-11-30", 
+#'            lang        = c("en", "de"),
+#'            file        = wp_cache_file()
 #'          )
 #'
 #' 
@@ -51,43 +48,15 @@ wp_trend <- function( page ,
                       from        = prev_month_start(), 
                       to          = prev_month_end(),
                       lang        = "en", 
-                      file        = "", 
-                      friendly,
-                      requestFrom,
-                      userAgent
+                      file        = "" 
 ){
   # dev # 
   # page="main"; from=prev_month_start(); to=prev_month_end(); lang="en"; file=""
   # page="main"; from=prev_month_start(); to=prev_month_end(); lang="en"; file="test.csv"
   # page="pegida"; from=prev_month_start(); to=Sys.Date(); lang="de"; file=""
   # deprecation
-  if( !missing("requestFrom") ) 
-    message("Option 'requestFrom' is deprecated and will cause errors 
-            in futuere versions of the wp_trend() function. Please read 
-            the package vignette and/or README to learn about the new
-            set of options.
-            
-            Check wp_http_header() to know which information are send to 
-            stats.grok.se (R and package versions)
-            ")
-  if( !missing("friendly") ) 
-    message("Option 'friendly' is deprecated and will cause errors 
-            in futuere versions of the wp_trend() function. Please read 
-            the package vignette and/or README to learn about the new
-            set of options.
-            
-            The package now is friendly by default.
-            ")
-  if( !missing("userAgent") ) 
-    message("Option 'userAgent' is deprecated and will cause errors 
-            in futuere versions of the wp_trend() function. Please read 
-            the package vignette and/or README to learn about the new
-            set of options.
-            
-            Check wp_http_header() to know which information are send to 
-            stats.grok.se (R and package versions)
-            ")
-
+  
+  # save current global save file
   old_cache_file <- wp_cache_file()
                           
   # input check
@@ -113,10 +82,13 @@ wp_trend <- function( page ,
   }
    
   # prepare URLs
-  urls <- wp_prepare_urls(page=page, 
-                          from=from, 
-                          to=to, 
-                          lang=lang)
+  urls <- 
+    wp_prepare_urls(
+      page=page, 
+      from=from, 
+      to=to, 
+      lang=lang
+    )
 
   # download data and extract data
   trash <- wp_get_data(urls)
@@ -136,6 +108,10 @@ wp_trend <- function( page ,
         ]
   rownames(res) <- NULL
   class(res) <- c("wp_df", "data.frame")
+  if( any(dim(res))>0 ){
+    res <- 
+      res[order(res$date, res$lang, res$title),]
+  }
   invisible(res)
 }
 
